@@ -20,24 +20,35 @@ Coordinate fitting and alignment --- :mod:`MDAnalysis.analysis.align`
 =====================================================================
 
 :Author: Oliver Beckstein, Joshua Adelman
-:Year: 2010--2011
+:Year: 2010--2013
 :Copyright: GNU Public License v3
 
 The module contains functions to fit a target structure to a reference
 structure. They use the fast QCP algorithm to calculate the root mean
-square distance (RMSD) between two coordinate sets and the rotation
-matrix *R* that minimizes the RMSD.
+square distance (RMSD) between two coordinate sets [Theobald2005]_ and
+the rotation matrix *R* that minimizes the RMSD [Liu2010]_. (Please
+cite these references when using this module.).
 
 Typically, one selects a group of atoms (such as the C-alphas),
-calculate the RMSD and transformation matrix, and apply the
+calculates the RMSD and transformation matrix, and applys the
 transformation to the current frame of a trajectory to obtain the
 rotated structure. The :func:`alignto` and :func:`rms_fit_trj`
 functions can be used to do this for individual frames and
 trajectories respectively.
 
-The RMS-fitting tutorial below shows how to do the individual steps
+The :ref:`RMS-fitting-tutorial` shows how to do the individual steps
 manually and explains the intermediate steps.
 
+.. SeeAlso::
+
+   :mod:`MDAnalysis.analysis.rms`
+        contains functions to compute RMSD (when structural alignment is not
+        required)
+   :mod:`MDAnalysis.core.qcprot`
+        implements the fast RMSD algorithm.
+
+
+.. _RMS-fitting-tutorial:
 
 RMS-fitting tutorial
 --------------------
@@ -122,13 +133,24 @@ function and then feed the resulting dictionary to :func:`rms_fit_trj`::
 
 (See the documentation of the functions for this advanced usage.)
 
-.. SeeAlso:: :mod:`MDAnalysis.core.qcprot` for the fast RMSD algorithm.
-
 
 Functions
 ---------
 
-.. Autogenerated list of module functions.
+.. autofunction:: rmsd
+.. autofunction:: alignto
+.. autofunction:: rms_fit_trj
+
+
+Helper functions
+----------------
+
+The following functions are used by the other functions in this
+module. They are probably of more interest to developers than to
+normal users.
+
+.. autofunction:: fasta2select
+.. autofunction:: check_same_atoms
 """
 
 import numpy
@@ -137,38 +159,14 @@ import MDAnalysis
 import MDAnalysis.core.qcprot as qcp
 from MDAnalysis import SelectionError
 from MDAnalysis.core.log import ProgressMeter
-from MDAnalysis.core.util import asiterable
+#from MDAnalysis.core.util import asiterable # unused
+from MDAnalysis.analysis.rms import rmsd, _process_selection
 
 import os.path
 
-
 import logging
 logger = logging.getLogger('MDAnalysis.analysis.align')
 
-def rmsd(a,b, weights=None):
-    """Returns RMSD between two coordinate sets *a* and *b*.
-
-    *a* and *b* are arrays of the coordinates of N atoms of shape N*3
-    as generated by, e.g.,
-    :meth:`MDAnalysis.core.AtomGroup.AtomGroup.coordinates`.
-
-    The *weights* can be an array of length N, containing e.g. masses
-    for a weighted RMSD calculation.
-
-    Example::
-     >>> u = Universe(PSF,DCD)
-     >>> bb = u.selectAtoms('backbone')
-     >>> A = bb.coordinates()  # coordinates of first frame
-     >>> u.trajectory[-1]      # forward to last frame
-     >>> B = bb.coordinates()  # coordinates of last frame
-     >>> rmsd(A,B)
-     6.8342494129169804
-    """
-    if not weights is None:
-        # weights are constructed as relative to the mean
-        weights = numpy.asarray(weights)/numpy.mean(weights)
-    return qcp.CalcRMSDRotationalMatrix(a.T.astype(numpy.float64),b.T.astype(numpy.float64),
-                                        a.shape[0], None, weights)
 
 def rotation_matrix(a,b, weights=None):
     """Returns the 3x3 rotation matrix for RMSD fitting coordinate sets *a* and *b*.
@@ -217,53 +215,9 @@ def rotation_matrix(a,b, weights=None):
                                         b.shape[0], rot, weights)
     return numpy.matrix(rot.reshape(3,3)), rmsd
 
-def _process_selection(select):
-    """Return a canonical selection dictionary.
-
-    :Arguments:
-      *select*
-         - any valid selection string for
-           :meth:`~MDAnalysis.core.AtomGroup.AtomGroup.selectAtoms` that produces identical
-           selections in *mobile* and *reference*; or
-         - dictionary ``{'mobile':sel1, 'reference':sel2}``.
-           The :func:`fasta2select` function returns such a
-           dictionary based on a ClustalW_ or STAMP_ sequence alignment.
-         - tuple ``(sel1, sel2)``
-
-    :Returns: dict with keys `reference` and `mobile`; the values are guaranteed to
-              be iterable (so that one can provide selections that retain order)
-    """
-    if type(select) is str:
-        select = {'reference':select,'mobile':select}
-    elif type(select) is tuple:
-        try:
-            select = {'mobile':select[0], 'reference':select[1]}
-        except IndexError:
-            raise IndexError("select must contain two selection strings "
-                             "(reference, mobile)")
-    elif type(select) is dict:
-        # compatability hack to use new nomenclature
-        try:
-            select['mobile'] = select['target']
-            warnings.warn("use key 'mobile' instead of deprecated 'target'; "
-                          "'target' will be removed in 0.8",
-                          DeprecationWarning)
-        except KeyError:
-            pass
-        try:
-            select['mobile']
-            select['reference']
-        except KeyError:
-            raise KeyError("select dictionary must contain entries for keys "
-                           "'mobile' and 'reference'.")
-    else:
-        raise TypeError("'select' must be either a string, 2-tuple, or dict")
-    select['mobile'] = asiterable(select['mobile'])
-    select['reference'] = asiterable(select['reference'])
-    return select
 
 def alignto(mobile, reference, select="all", mass_weighted=False,
-            subselection=None):
+            subselection=None, tol_mass=0.1):
     """Spatially align *mobile* to *reference* by doing a RMSD fit on *select* atoms.
 
     The superposition is done in the following way:
@@ -313,6 +267,9 @@ def alignto(mobile, reference, select="all", mass_weighted=False,
       *mass_weighted* : boolean
          ``True`` uses the masses :meth:`reference.masses` as weights for the
          RMSD fit.
+      *tol_mass*
+         Reject match if the atomic masses for matched atoms differ by more than
+         *tol_mass* [0.1]
       *subselection*
          Apply the transformation only to this selection.
 
@@ -329,6 +286,10 @@ def alignto(mobile, reference, select="all", mass_weighted=False,
 
     .. SeeAlso:: For RMSD-fitting trajectories it is more efficient to
                  use :func:`rms_fit_trj`.
+
+    .. versionchanged:: 0.8
+       Added check that the two groups describe the same atoms including
+       the new *tol_mass* keyword.
     """
     if select in ('all', None):
         # keep the EXACT order in the input AtomGroups; selectAtoms('all')
@@ -340,6 +301,9 @@ def alignto(mobile, reference, select="all", mass_weighted=False,
         select = _process_selection(select)
         mobile_atoms = mobile.selectAtoms(*select['mobile'])
         ref_atoms = reference.selectAtoms(*select['reference'])
+
+    check_same_atoms(ref_atoms, mobile_atoms, tol_mass=tol_mass)
+
     if mass_weighted:
         weights = ref_atoms.masses()/numpy.mean(ref_atoms.masses())
         ref_com = ref_atoms.centerOfMass()
@@ -374,9 +338,15 @@ def alignto(mobile, reference, select="all", mass_weighted=False,
 
 
 def rms_fit_trj(traj, reference, select='all', filename=None, rmsdfile=None, prefix='rmsfit_',
-                mass_weighted=False, tol_mass=0.1):
+                mass_weighted=False, tol_mass=0.1, force=True, quiet=False, **kwargs):
     """RMS-fit trajectory to a reference structure using a selection.
 
+    Both reference *ref* and trajectory *traj* must be
+    :class:`MDAnalysis.Universe` instances. If they contain a
+    trajectory then it is used. The output file format is determined
+    by the file extension of *filename*. One can also use the same
+    universe if one wants to fit to the current frame.
+
     :Arguments:
       *traj*
          trajectory, :class:`MDAnalysis.Universe` object
@@ -407,48 +377,61 @@ def rms_fit_trj(traj, reference, select='all', filename=None, rmsdfile=None, pre
       *tol_mass*
          Reject match if the atomic masses for matched atoms differ by more than
          *tol_mass* [0.1]
+      *force*
+         - ``True``: Overwrite an existing output trajectory (default)
+         - ``False``: simply return if the file already exists
+      *quiet*
+         - ``True``: suppress progress and logging for levels INFO and below.
+         - ``False``: show all status messages and do not change the the logging
+           level (default)
 
-    Both reference and trajectory must be :class:`MDAnalysis.Universe`
-    instances. If they contain a trajectory then it is used. The
-    output file format is the same as the input *traj*.
+         .. Note:: If
+
+
+      *kwargs*
+         All other keyword arguments are passed on the trajectory
+         :class:`~MDAnalysis.coordinates.base.Writer`; this allows manipulating/fixing
+         trajectories on the fly (e.g. change the output format by changing the extension of *filename*
+         and setting different parameters as described for the corresponding writer).
+
+    :Returns: *filename* (either provided or auto-generated)
 
     .. _ClustalW: http://www.clustal.org/
     .. _STAMP: http://www.compbio.dundee.ac.uk/manuals/stamp.4.2/
+
+    .. versionchanged:: 0.8
+       Added *kwargs* to be passed to the trajectory :class:`~MDAnalysis.coordinates.base.Writer` and
+       *filename* is returned.
     """
 
     frames = traj.trajectory
 
+    if quiet:
+        # should be part of a try ... finally to guarantee restoring the log level
+        logging.disable(logging.WARN)
+
+    kwargs.setdefault('remarks', 'RMS fitted trajectory to reference')
     if filename is None:
         path,fn = os.path.split(frames.filename)
         filename = os.path.join(path,prefix+fn)
-        writer = frames.Writer(filename, remarks='RMS fitted trajectory to reference')
+        _Writer = frames.Writer
     else:
-        writer = frames.OtherWriter(filename)
+        _Writer = frames.OtherWriter
+    if os.path.exists(filename) and not force:
+        logger.warn("{0} already exists and will NOT be overwritten; use force=True if you want this".format(filename))
+        return filename
+    writer = _Writer(filename, **kwargs)
+    del _Writer
 
     select = _process_selection(select)
 
     ref_atoms = reference.selectAtoms(*select['reference'])
     traj_atoms = traj.selectAtoms(*select['mobile'])
     natoms = traj_atoms.numberOfAtoms()
-    if len(ref_atoms) != len(traj_atoms):
-        raise SelectionError("Reference and trajectory atom selections do not contain "+
-                             "the same number of atoms: N_ref=%d, N_traj=%d" % \
-                             (len(ref_atoms), len(traj_atoms)))
-    logger.info("RMS-fitting on %d atoms." % len(ref_atoms))
-    mass_mismatches = (numpy.absolute(ref_atoms.masses() - traj_atoms.masses()) > tol_mass)
-    if numpy.any(mass_mismatches):
-        # diagnostic output:
-        logger.error("Atoms: reference | trajectory")
-        for ar,at in zip(ref_atoms,traj_atoms):
-            if ar.name != at.name:
-                logger.error("%4s %3d %3s %3s %6.3f  |  %4s %3d %3s %3s %6.3f" %  \
-                      (ar.segid, ar.resid, ar.resname, ar.name, ar.mass,
-                       at.segid, at.resid, at.resname, at.name, at.mass,))
-        errmsg = "Inconsistent selections, masses differ by more than %f; mis-matching atoms are shown above." % tol_mass
-        logger.error(errmsg)
-        raise SelectionError(errmsg)
-    del mass_mismatches
 
+    check_same_atoms(ref_atoms, traj_atoms, tol_mass=tol_mass)
+
+    logger.info("RMS-fitting on %d atoms." % len(ref_atoms))
     if mass_weighted:
         # if performing a mass-weighted alignment/rmsd calculation
         weight = ref_atoms.masses()/ref_atoms.masses().mean()
@@ -473,7 +456,7 @@ def rms_fit_trj(traj, reference, select='all', filename=None, rmsdfile=None, pre
     rot = numpy.zeros(9,dtype=numpy.float64)      # allocate space for calculation
     R = numpy.matrix(rot.reshape(3,3))
 
-    percentage = ProgressMeter(nframes, interval=10,
+    percentage = ProgressMeter(nframes, interval=10, quiet=quiet,
                                format="Fitted frame %(step)5d/%(numsteps)d  [%(percentage)5.1f%%]\r")
 
     for k,ts in enumerate(frames):
@@ -506,6 +489,12 @@ def rms_fit_trj(traj, reference, select='all', filename=None, rmsdfile=None, pre
         numpy.savetxt(rmsdfile,rmsd)
         logger.info("Wrote RMSD timeseries  to file %r", rmsdfile)
 
+    if quiet:
+        # should be part of a try ... finally to guarantee restoring the log level
+        logging.disable(logging.NOTSET)
+
+    return filename
+
 def fasta2select(fastafilename,is_aligned=False,
                  ref_resids=None, target_resids=None,
                  ref_offset=0,target_offset=0,verbosity=3,
@@ -694,3 +683,46 @@ def fasta2select(fastafilename,is_aligned=False,
     target_selection =  " or ".join(sel[1])
     return {'reference':ref_selection, 'mobile':target_selection}
 
+
+def check_same_atoms(ag1, ag2, tol_mass=0.1):
+    """Test if the two :class:`~MDAnalysis.core.AtomGroup.AtomGroup` *ag1* and *ag2* consist of the same atoms.
+
+    Two tests are performed:
+
+    1. The two groups must contain the same number of atoms.
+    2. The masses of corresponding atoms are compared and if any masses differ by more
+       than *tol_mass* the test is considered failed.
+
+    :Arguments:
+      *ag1*, *ag2*
+         :class:`~MDAnalysis.core.AtomGroup.AtomGroup` instances that are compared
+    :Keywords:
+      *tol_mass*
+         Reject if the atomic masses for matched atoms differ by more than
+         *tol_mass* [0.1]
+
+    :Raises: :exc:`SelectionError` if any of the tests fails.
+
+    .. versionadded:: 0.8
+    """
+
+    if len(ag1) != len(ag2):
+        # Test 1 failed
+        errmsg = "Reference and trajectory atom selections do not contain "\
+            "the same number of atoms: N_ref={0}, N_traj={1}".format(len(ag1), len(ag2))
+        logger.error(errmsg)
+        raise SelectionError(errmsg)
+    mass_mismatches = (numpy.absolute(ag1.masses() - ag2.masses()) > tol_mass)
+    if numpy.any(mass_mismatches):
+        # Test 2 failed.
+        # diagnostic output:
+        logger.error("Atoms: reference | trajectory")
+        for ar,at in zip(ag1, ag2):
+            if ar.name != at.name:
+                logger.error("%4s %3d %3s %3s %6.3f  |  %4s %3d %3s %3s %6.3f" %  \
+                      (ar.segid, ar.resid, ar.resname, ar.name, ar.mass,
+                       at.segid, at.resid, at.resname, at.name, at.mass,))
+        errmsg = "Inconsistent selections, masses differ by more than {0}; mis-matching atoms are shown above.".format(tol_mass)
+        logger.error(errmsg)
+        raise SelectionError(errmsg)
+    return True
