@@ -27,13 +27,13 @@ Generating densities from trajectories --- :mod:`MDAnalysis.analysis.density`
 :Year: 2011
 :Copyright: GNU Public License v3
 
-The module provides classes and functions to represent volumetric data, in
-particular densities.
+The module provides classes and functions to generate and represent
+volumetric data, in particular densities.
 
 Generating a density from a MD trajectory
 -----------------------------------------
 
-As an input a trajectory is required that
+An input trajectory is required that
 
 1. Has been centered on the protein of interest.
 2. Has all molecules made whole that have been broken across periodic
@@ -44,6 +44,7 @@ As an input a trajectory is required that
 
 To generate the density of water molecules around a protein::
 
+  from MDAnalysis.analysis.density import density_from_Universe
   u = Universe(PSF,DCD)
   D = density_from_Universe(u, delta=1.0, atomselection="name OH2")
   D.convert_density('TIP3P')
@@ -383,20 +384,19 @@ def density_from_trajectory(*args,**kwargs):
          density_from_trajectory(PDB, XTC, delta=1.0, atomselection='name OH2', ...) --> density
 
     :Arguments:
-      psf/pdb/gro
-            topology file
-      dcd/xtc/trr/pdb
-            trajectory; if reading a single PDB file it is sufficient to just provide it
-            once as a single argument
+      topology file
+            any topology file understood by MDAnalysis
+      trajectory
+            any trajectory (coordinate) file understood by MDAnalysis;
+            if reading a single PDB file it is sufficient to just
+            provide it once as a single argument
 
     :Keywords:
       atomselection
             selection string (MDAnalysis syntax) for the species to be analyzed
             ["name OH2"]
       delta
-            approximate bin size for the density grid in Angstroem (same in x,y,z)
-            (It is slightly adjusted when the box length is not an integer multiple
-            of delta.) [1.0]
+            bin size for the density grid in Angstroem (same in x,y,z) [1.0]
       metadata
             dictionary of additional data to be saved with the object
       padding
@@ -430,9 +430,7 @@ def density_from_Universe(universe,delta=1.0,atomselection='name OH2',
             selection string (MDAnalysis syntax) for the species to be analyzed
             ["name OH2"]
       delta
-            approximate bin size for the density grid in Angstroem (same in x,y,z)
-            (It is slightly adjusted when the box length is not an integer multiple
-            of delta.) [1.0]
+            bin size for the density grid in Angstroem (same in x,y,z) [1.0]
       metadata
             dictionary of additional data to be saved with the object
       padding
@@ -547,16 +545,16 @@ def notwithin_coordinates_factory(universe,sel1, sel2, cutoff, not_within=True,
       coord = notwithin_coordinates(cutoff2) # can use different cut off
 
     :Keywords:
-      not_within
+      *not_within*
          True: selection behaves as 'not within' (As described above)
          False: selection is a <sel1> WITHIN <cutoff> OF <sel2>'
-      use_kdtree
+      *use_kdtree*
          True: use fast kd-tree based selections (requires new MDAnalysis >= 0.6)
          False: use distance matrix approach
 
     .. Note::
 
-       * Periodic boundary conditions are NOT taken into account: the naive
+       * Periodic boundary conditions are *not* taken into account: the naive
          minimum image convention employed in the distance check is currently
          not being applied to remap the coordinates themselves, and hence it
          would lead to counts in the wrong region.
@@ -610,12 +608,23 @@ def notwithin_coordinates_factory(universe,sel1, sel2, cutoff, not_within=True,
 
 
 def Bfactor2RMSF(B):
-    """Atomic root mean square fluctuation (in Angstrom) from the crystallographic B-factor
+    r"""Atomic root mean square fluctuation (in Angstrom) from the crystallographic B-factor
 
-    B = [(8*PI**2)/3] * (RMSF)**2
+    RMSF and B-factor are related by [Willis1975]_
 
-    Willis & Pryor, Thermal vibrations in crystallography, Cambridge
-    Univ. Press, 1975
+    .. math::
+
+        B = \frac{8\pi^2}{3} \rm{RMSF}^2
+
+    and this function returns
+
+    .. math::
+
+        \rm{RMSF} = \sqrt{\frac{3 B}{8\pi^2}}
+
+    .. rubric:: References
+
+    .. [Willis1975]  BTM Willis and AW Pryor. *Thermal vibrations in crystallography*. Cambridge Univ. Press, 1975
     """
     return numpy.sqrt(3.*B/8.)/numpy.pi
 
@@ -627,11 +636,9 @@ def density_from_PDB(pdb, **kwargs):
     centered at each selected atoms. If B-factors are present in the
     file then they are used to calculate the width of the gaussian.
 
-    Using the `sigma` keyword, one can override this choice and
+    Using the *sigma* keyword, one can override this choice and
     prescribe a gaussian width for all atoms (in Angstrom), which is
-    calculated as
-
-      B = [(8*PI**2)/3] * (RMSF)**2
+    calculated as described for :func:`Bfactor2RMSF`.
 
     .. Note::
 
@@ -651,9 +658,7 @@ def density_from_PDB(pdb, **kwargs):
           selection string (MDAnalysis syntax) for the species to be analyzed
           ['resname HOH and name O']
        *delta*
-          approximate bin size for the density grid (same in x,y,z)
-          (It is slightly adjusted when the box length is not an integer multiple
-          of delta.) [1.0]
+          bin size for the density grid in Angstroem (same in x,y,z) [1.0]
        *metadata*
           dictionary of additional data to be saved with the object [``None``]
        *padding*
@@ -710,9 +715,7 @@ class BfactorDensityCreator(object):
           atomselection
             selection string (MDAnalysis syntax) for the species to be analyzed
           delta
-            approximate bin size for the density grid (same in x,y,z)
-            (It is slightly adjusted when the box length is not an integer multiple
-            of delta.)
+            bin size for the density grid in Angstroem (same in x,y,z) [1.0]
           metadata
             dictionary of additional data to be saved with the object
           padding
