@@ -62,7 +62,7 @@ class DCDWriter(base.Writer):
            comments to annotate dcd file
          *convert_units*
            units are converted to the MDAnalysis base format; ``None`` selects
-           the value of :data:`MDAnalysis.core.flags` ['convert_gromacs_lengths'].
+           the value of :data:`MDAnalysis.core.flags` ['convert_lengths'].
            (see :ref:`flags-label`)
         """
         if numatoms == 0:
@@ -74,7 +74,7 @@ class DCDWriter(base.Writer):
                                  "For example: numatoms=universe.atoms.numberOfAtoms()")
         self.filename = filename
         if convert_units is None:
-            convert_units = MDAnalysis.core.flags['convert_gromacs_lengths']
+            convert_units = MDAnalysis.core.flags['convert_lengths']
         self.convert_units = convert_units    # convert length and time to base units on the fly?
         self.numatoms = numatoms
 
@@ -82,7 +82,7 @@ class DCDWriter(base.Writer):
         self.start = start
         self.step = step
         self.delta = delta
-        self.dcdfile = file(self.filename, 'wb')
+        self.dcdfile = open(self.filename, 'wb')
         self.remarks = remarks
         self._write_dcd_header(numatoms, start, step, delta, remarks)
     def _dcd_header(self):
@@ -145,6 +145,13 @@ class DCDWriter(base.Writer):
             pos = self.convert_pos_to_native(ts._pos, inplace=False)  # possibly make a copy to avoid changing the trajectory
         self._write_next_frame(pos[:,0], pos[:,1], pos[:,2], unitcell)
         self.frames_written += 1
+    def convert_dimensions_to_unitcell(self, ts, _ts_order=[0,3,1,4,5,2]):
+        """Read dimensions from timestep *ts* and return appropriate unitcell
+           as [A,alpha,B,beta,gamma,C]"""
+        unitcell = super(DCDWriter, self).convert_dimensions_to_unitcell(ts)
+        # unitcell is A,B,C,alpha,beta,gamma - convert to order expected by low level
+        # DCD routines
+        return numpy.take(unitcell, _ts_order)
     def close(self):
         """Close trajectory and flush buffers."""
         self._finish_dcd_write()
@@ -192,7 +199,7 @@ class DCDReader(base.Reader):
         if stats.st_size == 0:
             raise IOError(errno.ENODATA,"DCD file is zero size",dcdfilename)
 
-        self.dcdfile = file(dcdfilename, 'rb')
+        self.dcdfile = open(dcdfilename, 'rb')
         self.numatoms = 0
         self.numframes = 0
         self.fixed = 0
