@@ -174,6 +174,14 @@ implemented. The Biopython Reader/Writer can be selected when loading data into
 a :class:`~MDAnalysis.core.AtomGroup.Universe` by providing the keyword
 *permissive* = ``False``.
 
+The Biopython PDB parser :class:`Bio.PDB.PDBParser` is fairly strict and even
+in its own permissive mode (which MDAnalysis employs) typically warns about
+missing element names with a
+:exc:`Bio.PDB.PDBExceptions.PDBConstructionWarning` . Such warnings, however,
+are generally harmless and therefore are filtered (and ignored) by MDAnalysis
+with the help of :func:`warnings.filterwarnings`.
+
+
 Classes
 ~~~~~~~
 
@@ -193,11 +201,15 @@ References
 .. _END: http://www.wwpdb.org/documentation/format32/sect11.html#END
 
 """
-from __future__ import with_statement
 
 try:
     # BioPython is overkill but potentially extensible (altLoc etc)
     import Bio.PDB
+    import pdb.extensions
+    # disable PDBConstructionWarning from picky builder
+    import warnings
+    warnings.filterwarnings("ignore", category=Bio.PDB.PDBExceptions.PDBConstructionWarning,
+                            message="Could not assign element|Used element .* for Atom")
 except ImportError:
     # TODO: fall back to PrimitivePDBReader
     raise ImportError("No full-feature PDB I/O functionality. Install biopython.")
@@ -209,7 +221,6 @@ import numpy
 import MDAnalysis.core
 import MDAnalysis.core.util as util
 import base
-import pdb.extensions
 
 from MDAnalysis.topology.core import guess_atom_element
 from MDAnalysis.core.AtomGroup import Universe, AtomGroup
@@ -249,7 +260,7 @@ class PDBReader(base.Reader):
         self.pdbfilename = pdbfilename
         self.filename = self.pdbfilename
         if convert_units is None:
-            convert_units = MDAnalysis.core.flags['convert_gromacs_lengths']
+            convert_units = MDAnalysis.core.flags['convert_lengths']
         self.convert_units = convert_units  # convert length and time to base units
 
         pdb_id = "0UNK"
@@ -325,7 +336,7 @@ class PDBWriter(base.Writer):
     sophistiocated writer is employed).
 
     .. Note::
-    
+
        The standard PDBWriter can only write the *whole system*.  In
        order to write a selection, use the :class:`PrimitivePDBWriter` ,
        which happens automatically when the
@@ -344,13 +355,13 @@ class PDBWriter(base.Writer):
 
     def __init__(self, pdbfilename, universe=None, multi=False, **kwargs):
         """pdbwriter = PDBWriter(<pdbfilename>,universe=universe,**kwargs)
-        
+
         :Arguments:
           pdbfilename     filename; if multi=True, embed a %%d formatstring
                           so that write_next_timestep() can insert the frame number
-                        
+
           universe        supply a universe [really REQUIRED; optional only for compatibility]
-        
+
           multi           False: write a single structure to a single pdb
                           True: write all frames to multiple pdb files
         """
@@ -407,10 +418,11 @@ class PDBWriter(base.Writer):
 class PrimitivePDBReader(base.Reader):
     """PDBReader that reads a PDB-formatted file, no frills.
 
-    Records read (see `PDB coordinate section`_ for details):
-     - CRYST1 for unitcell A,B,C, alpha,beta,gamm
-     - ATOM or HETATM for x,y,z
+    The following PDB records are parsed (see `PDB coordinate section`_ for details):
+     - CRYST1 for unitcell A,B,C, alpha,beta,gamma
+     - ATOM or HETATM for serial,name,resName,chainID,resSeq,x,y,z,occupancy,tempFactor
      - HEADER, TITLE, COMPND
+     - all other lines are ignored
 
     Reads multi-`MODEL`_ PDB files as trajectories.
 
@@ -462,17 +474,23 @@ class PrimitivePDBReader(base.Reader):
         If the pdb file contains multiple MODEL records then it is
         read as a trajectory where the MODEL numbers correspond to
         frame numbers. Therefore, the MODEL numbers must be a sequence
-        of integeres (typically starting at 1 or 0).
+        of integers (typically starting at 1 or 0).
         """
         self.filename = filename
         if convert_units is None:
-            convert_units = MDAnalysis.core.flags['convert_gromacs_lengths']
+            convert_units = MDAnalysis.core.flags['convert_lengths']
         self.convert_units = convert_units  # convert length and time to base units
 
-        # add this number to the MODEL number to get frame: typically
-        # PDB starts at 1 but Gromacs trjconv exports starting with
-        # MODEL 0. (MODEL 0 is autodetected in the code, though!)
-        self.model_offset = kwargs.pop("model_offset", -1)
+        # = NOTE to clear up confusion over 0-based vs 1-based frame numbering =
+        # self.frame is 1-based for this Reader, which matches the behavior of
+        # the MODEL record in a typical multi-model PDB file.  If the MODEL
+        # record is 0-based, this is accounted for by __init__.
+        # self._read_frame assumes that it is passed a 0-based frame number, so
+        # that it functions as expected when slicing is used.
+
+        # If MODEL number in the PDB file is 0-based, then this model_offset
+        # will be set to 1 by __init__.
+        self.model_offset = kwargs.pop("model_offset", 0)
 
         header = ""
         compound = []
@@ -484,34 +502,37 @@ class PrimitivePDBReader(base.Reader):
 
         unitcell = numpy.zeros(6, dtype=numpy.float32)
 
+        class Struct:
+            def __init__(self, **entries):
+                self.__dict__.update(entries)
+
         with util.openany(filename, 'r') as pdbfile:
             for i, line in enumerate(pdbfile):
+                line = line.strip() # Remove extra spaces
+                if len(line) == 0: # Skip line if empty
+                    continue
+                record = line[:6].strip()
                 def _c(start, stop, typeclass=float):
                     return self._col(line, start, stop, typeclass=typeclass)
-                if line.split()[0] == 'END':
+                if record == 'END':
                     break
-                elif line[:6] == 'CRYST1':
+                elif record == 'CRYST1':
                     A, B, C = _c(7, 15), _c(16, 24), _c(25, 33)
                     alpha, beta, gamma = _c(34, 40), _c(41, 47), _c(48, 54)
                     unitcell[:] = A, B, C, alpha, beta, gamma
                     continue
-                elif line[:6] == 'HEADER':
+                elif record == 'HEADER':
                     header = line[6:-1]
                     continue
-                elif line[:6] == 'COMPND':
+                elif record == 'COMPND':
                     l = line[6:-1]
                     compound.append(l)
                     continue
-                elif line[:6] == 'REMARK':
+                elif record == 'REMARK':
                     content = line[6:-1]
                     remarks.append(content)
-                elif line[:5] == 'MODEL':
-                    frameno = int(line.split()[1])
-                    if frameno == 0:
-                        # detect if MODEL starts at 0 or at 1; switch model_offset appropriately
-                        # Will break/loose frames if MODELs are renumbered in the PDB file...
-                        self.model_offset = 0
-                    frames[frameno + self.model_offset] = i # 0-based indexing
+                elif record == 'MODEL':
+                    frames[len(frames) + 1] = i  # 1-based indexing
                 elif line[:6] in ('ATOM  ', 'HETATM'):
                     # skip atom/hetatm for frames other than the first - they will be read in when next() is called on the trajectory reader
                     if len(frames) > 1:
@@ -521,15 +542,22 @@ class PrimitivePDBReader(base.Reader):
                     name = _c(13, 16, str).strip()
                     resName = _c(18, 21, str).strip()
                     chainID = _c(22, 22, str)  # empty chainID is a single space ' '!
-                    resSeq = _c(23, 26, int)
+                    if self.format == "XPDB":
+                        resSeq = _c(23, 27, int)  # extended non-standard format used by VMD
+                    else:
+                        assert self.format == "PDB"
+                        resSeq = _c(23, 26, int)
+                        insertCode = _c(27, 27, str)  # not used
                     x, y, z = _c(31, 38), _c(39, 46), _c(47, 54)
                     occupancy = _c(55, 60)
                     tempFactor = _c(61, 66)
                     segID = _c(67, 76, str).strip()
                     element = _c(77, 78, str).strip()
                     coords.append((x, y, z))
-                    atoms.append((serial, name, resName, chainID, resSeq, occupancy, tempFactor, segID, element))
-                    continue
+                    atom = Struct(**dict(zip(("serial", "name", "resName", "chainID", "resSeq", "occupancy", "tempFactor", "segID", "element"),\
+                                                 (serial, name, resName, chainID, resSeq, occupancy, tempFactor, segID, element))))
+                    atoms.append(atom)
+
         self.header = header
         self.compound = compound
         self.remarks = remarks
@@ -543,7 +571,7 @@ class PrimitivePDBReader(base.Reader):
 
         # No 'MODEL' entries
         if len(frames) == 0:
-            frames[0] = 0
+            frames[1] = 0
 
         self.frames = frames
         self.numframes = len(frames) if frames else 1
@@ -552,8 +580,8 @@ class PrimitivePDBReader(base.Reader):
         self.periodic = False
         self.delta = 0
         self.skip_timestep = 1
-        # hack for PrimitivePDBParser:
-        self._atoms = numpy.rec.fromrecords(atoms, names="serial,name,resName,chainID,resSeq,occupancy,tempFactor,segID,element")
+
+        self._atoms = atoms
 
     def _col(self, line, start, stop, typeclass=float):
         """Pick out and convert the columns start-stop.
@@ -610,18 +638,27 @@ class PrimitivePDBReader(base.Reader):
             except IOError:
                 raise StopIteration
 
+    #def __getitem__(self,frame):
+    #    return self._read_frame(frame+1)
+
     def _read_next_timestep(self, ts=None):
         if ts is None:
             ts = self.ts
         else:
             # TODO: cleanup _read_frame() to use a "free" Timestep
             raise NotImplementedError("PrimitivePDBReader cannot assign to a timestep")
-        frame = self.frame + 1
+        # frame is 1-based. Normally would add 1 to frame before calling
+        # self._read_frame to retrieve the subsequent ts. But self._read_frame
+        # assumes it is being passed a 0-based frame, and adjusts.
+        frame = self.frame
         return self._read_frame(frame)
 
     def _read_frame(self, frame):
         if numpy.dtype(type(frame)) != numpy.dtype(int):
             raise TypeError("frame must be a integer")
+        # Assume _read_frame is passed a 0-based frame number. Convert this to
+        # 1-based.
+        frame += 1
         try:
             line = self.frames[frame]
         except KeyError:
@@ -645,6 +682,8 @@ class PrimitivePDBReader(base.Reader):
             for line in f:
                 if line[:6] == 'ENDMDL':
                     break
+                # NOTE - CRYST1 line won't be found if it comes before the MODEL line,
+                # which is sometimes the case, e.g. output from gromacs trjconv
                 elif line[:6] == 'CRYST1':
                     A, B, C = _c(7, 15), _c(16, 24), _c(25, 33)
                     alpha, beta, gamma = _c(34, 40), _c(41, 47), _c(48, 54)
@@ -667,7 +706,7 @@ class PrimitivePDBReader(base.Reader):
         if self.convert_units:
             self.convert_pos_from_native(self.ts._pos)             # in-place !
             self.convert_pos_from_native(self.ts._unitcell[:3])    # in-place ! (only lengths)
-        self.ts.frame = frame+1   # frame labels are 1-based (confusing ...)
+        self.ts.frame = frame
         return self.ts
 
 
@@ -735,8 +774,8 @@ class PrimitivePDBWriter(base.Writer):
     remark_max_length = 66
     _multiframe = False
 
-    def __init__(self, filename, numatoms=None, start=0, step=1, remarks="Created by PrimitivePDBWriter",
-                 convert_units=None, bonds=False, multiframe=None):
+    def __init__(self, filename, bonds="conect", numatoms=None, start=0, step=1, remarks="Created by PrimitivePDBWriter",
+                 convert_units=None, multiframe=None):
         """Create a new PDBWriter
 
         :Arguments:
@@ -753,7 +792,7 @@ class PrimitivePDBWriter(base.Writer):
            characters) being wrapped.
          *convert_units*
            units are converted to the MDAnalysis base format; ``None`` selects
-           the value of :data:`MDAnalysis.core.flags` ['convert_gromacs_lengths']
+           the value of :data:`MDAnalysis.core.flags` ['convert_lengths']
          *bonds*
            write bonds to the PDB file as CONECT_ records [``False``]
 
@@ -784,7 +823,7 @@ class PrimitivePDBWriter(base.Writer):
 
         self.filename = filename
         if convert_units is None:
-            convert_units = MDAnalysis.core.flags['convert_gromacs_lengths']
+            convert_units = MDAnalysis.core.flags['convert_lengths']
         self.convert_units = convert_units  # convert length and time to base units
         self.multiframe = self._multiframe if multiframe is None else multiframe
         self.bonds = bonds
@@ -899,13 +938,44 @@ class PrimitivePDBWriter(base.Writer):
             return
 
         if self.obj.atoms.numberOfAtoms() != self.obj.universe.atoms.numberOfAtoms():
-            logger.error("PDB CONECT records not written because this only works correctly for a whole Universe.")
-            raise NotImplementedError("PDB CONECT records not written because this only works correctly for a whole Universe.")
+            pass
+            #logger.error("PDB CONECT records not written because this only works correctly for a whole Universe.")
+            #raise NotImplementedError("PDB CONECT records not written because this only works correctly for a whole Universe.")
+
+        bonds = set()
+
+        [[bonds.add(b) for b in a.bonds] for a in self.obj.atoms]
+
+        atoms = set([a.number for a in self.obj.atoms])
+
+        mapping = dict([(atom.number, i) for i, atom in enumerate(self.obj.atoms)])
+
+        # Write out only the bonds that were defined in CONECT records
+        if self.bonds == "conect":
+            bonds = [(bond.atom1.number, bond.atom2.number) for bond in bonds if not bond.is_guessed]
+        elif self.bonds == "all":
+            bonds = [(bond.atom1.number, bond.atom2.number) for bond in bonds]
+        else :
+            raise ValueError("bonds has to be either None, 'conect' or 'all'")
+        con = {}
+
+        for a1, a2 in bonds:
+             if not (a1 in atoms and a2 in atoms): continue
+             if not con.has_key(a1): con[a1] = []
+             if not con.has_key(a2): con[a2] = []
+             con[a2].append(a1)
+             con[a1].append(a2)
+
+        #print con
+        atoms = sorted([a.number for a in self.obj.atoms])
+
+        conect = [([a,] + sorted(con[a])) for a in atoms if con.has_key(a)]
+
+        conect = [[mapping[e] for e in row] for row in conect]
+
+        for c in conect:
+            self.CONECT(c)
 
-        for conect in self.obj.universe.bonds:
-            # TODO: could add logic here to re-number (need a dict converting between atom numbers in Universe/bonds
-            #       and in the selection)
-            self.CONECT(conect)
 
     def _update_frame(self, obj):
         """Method to initialize important attributes in writer from a AtomGroup or Universe *obj*.
@@ -932,7 +1002,7 @@ class PrimitivePDBWriter(base.Writer):
         ts, traj = None, None
         if hasattr(obj, 'universe') and not isinstance(obj, Universe):
             # For AtomGroup and children (Residue, ResidueGroup, Segment)
-            ts = obj.ts
+            ts = obj.universe.trajectory.ts
             traj = obj.universe.trajectory
         else:
             # For Universe only
@@ -1072,6 +1142,9 @@ class PrimitivePDBWriter(base.Writer):
         else:
             coor = ts._pos
 
+        if hasattr(self.obj, "indices"):
+            coor = coor[self.obj.indices()]
+
         if len(atoms) != len(coor):
             raise ValueError("Length of the atoms array is %d, this is different form the Timestep coordinate array %d" % (len(atoms), len(ts._pos)))
 
@@ -1243,11 +1316,29 @@ class PrimitivePDBWriter(base.Writer):
         .. _CONECT: http://www.wwpdb.org/documentation/format32/sect10.html#CONECT
 
         """
-        conect = ["%5d" % entry for entry in conect]
+        conect = ["%5d" % (entry+1) for entry in conect]
         conect = "".join(conect)
         self.pdbfile.write(self.fmt['CONECT'] % conect)
 
 
+class ExtendedPDBReader(PrimitivePDBReader):
+    """PDBReader that reads a PDB-formatted file with five-digit residue numbers.
+
+    This reader does not conform to the `PDB standard`_ because it allows
+    five-digit residue numbers that may take up columns 23 to 27 (inclusive)
+    instead of being confined to 23-26 (with column 27 being reserved for the
+    insertion code in the PDB standard). PDB files in this format are written
+    by popular programs such as VMD_.
+
+    .. SeeAlso:: :class:`PrimitivePDBReader`
+
+    .. _PDB standard: http://www.wwpdb.org/documentation/format32/sect9.html
+    .. _VMD: http://www.ks.uiuc.edu/Research/vmd/
+
+    .. versionadded:: 0.8
+    """
+    format = "XPDB"
+
 class MultiPDBWriter(PrimitivePDBWriter):
     """PDB writer that implements a subset of the `PDB 3.2 standard`_ .
 
@@ -1260,7 +1351,7 @@ class MultiPDBWriter(PrimitivePDBWriter):
 
     .. _`PDB 3.2 standard`:
        http://www.wwpdb.org/documentation/format32/v3.2.html
-       
+
     .. _MODEL: http://www.wwpdb.org/documentation/format32/sect9.html#MODEL
     .. _ENDMDL: http://www.wwpdb.org/documentation/format32/sect9.html#ENDMDL
     .. _CONECT: http://www.wwpdb.org/documentation/format32/sect10.html#CONECT
