@@ -83,7 +83,6 @@ option are guaranteed to conform to the above format::
 .. _PDB:     http://www.rcsb.org/pdb/info.html#File_Formats_and_Standards
 """
 
-from __future__ import with_statement
 import numpy
 
 import MDAnalysis.core
@@ -116,7 +115,7 @@ class PQRReader(base.Reader):
         """
         self.filename = filename
         if convert_units is None:
-            convert_units = MDAnalysis.core.flags['convert_gromacs_lengths']
+            convert_units = MDAnalysis.core.flags['convert_lengths']
         self.convert_units = convert_units  # convert length and time to base units
 
         coords = []
