@@ -53,6 +53,30 @@ appropriate reader automatically.
 .. _duck typing: http://c2.com/cgi/wiki?DuckTyping
 
 
+Using Readers
+-------------
+
+Normally, one does not explicitly need to select a reader. This is handled
+automatically when creating a :class:`~MDAnalysis.core.AtomGroup.Universe` and
+the appropriate reader for the file type is selected (typically by the file
+extension but this choice can be overriden with the ``format`` argument to
+:class:`~MDAnalysis.core.AtomGroup.Universe`).
+
+Using Writers
+-------------
+
+A typical approach is to generate a new trajectory from an old one, e.g. to
+only keep the protein::
+
+  u = MDAnalysis.Universe(PDB, XTC)
+  protein = u.selectAtoms("protein")
+  with MDAnalysis.Writer("protein.xtc", protein.numberOfAtoms()) as W:
+      for ts in u.trajectory:
+          W.write(protein)
+
+Using the :func:`with` statement will automatically close the trajectory when
+the last frame has been written.
+
 
 Supported coordinate formats
 ----------------------------
@@ -109,6 +133,11 @@ also recognized when they are compressed with :program:`gzip` or
    |               |           |       | are supported but require the *multiframe* keyword.  |
    |               |           |       | Module :mod:`MDAnalysis.coordinates.PDB`             |
    +---------------+-----------+-------+------------------------------------------------------+
+   | XPDB          | pdb       |   r   | Extended PDB format (can use 5-digit residue         |
+   |               |           |       | numbers). To use, specify the format "XPBD"          |
+   |               |           |       | explicitly: ``Universe(..., format="XPDB")``.        |
+   |               |           |       | Module :MDAnalysis.coordinates.PDB`                  |
+   +---------------+-----------+-------+------------------------------------------------------+
    | PDBQT [#a]_   | pdbqt     | r/w   | file format used by AutoDock with atom types *t*     |
    |               |           |       | and partial charges *q*. Module:                     |
    |               |           |       | :mod:`MDAnalysis.coordinates.PDBQT`                  |
@@ -124,6 +153,12 @@ also recognized when they are compressed with :program:`gzip` or
    |               |           |       | either standard or EXTended format. Module           |
    |               |           |       | :mod:`MDAnalysis.coordinates.CRD`                    |
    +---------------+-----------+-------+------------------------------------------------------+
+   | DESRES [#a]_  | dms       |  r    | DESRES Molecular Structure file format reader.       |
+   |               |           |       | Module :mod:`MDAnalysis.coordinates.DMS`             |
+   +---------------+-----------+-------+------------------------------------------------------+
+   | IBIsCO/YASP   | trz       |  r/w  | Binary IBIsCO or YASP trajectories Module            |
+   |               |           |       | :mod:`MDAnalysis.coordinates.TRZ`                    |
+   +---------------+-----------+-------+------------------------------------------------------+
 
 .. [#a] This format can also be used to provide basic *topology*
    information (i.e. the list of atoms); it is possible to create a
@@ -164,9 +199,10 @@ History
 - 2012-02-11 added _velocities to Timestep
 - 2012-05-24 multiframe keyword to distinguish trajectory from single frame writers
 - 2012-06-04 missing implementations of Reader.__getitem__ should raise :exc:`TypeError`
+- 2013-08-02 Readers/Writers must conform to the Python `Context Manager`_ API
 
 .. _Issue 49: http://code.google.com/p/mdanalysis/issues/detail?id=49
-
+.. _Context Manager: http://docs.python.org/2/reference/datamodel.html#context-managers
 
 Registry
 ~~~~~~~~
@@ -211,7 +247,7 @@ Methods
             update the Timesteps positions array with the contents of *arg*
 
       Anything else raises an exception; in particular it is not possible to
-      create a "empty" :class:`Timestep` instance.
+      create a "empty" :class:`~MDAnalysis.coordinates.base.Timestep` instance.
   ``__getitem__(atoms)``
       position(s) of atoms; can be a slice or numpy array and then returns
       coordinate array
@@ -232,7 +268,7 @@ Attributes
   ``dimensions``
       system box dimensions (`x, y, z, alpha, beta, gamma`)
       (typically implemented as a property because it needs to translate whatever is in the
-      underlying :attr:`Timestep._unitcell` attribute)
+      underlying :class:`~MDAnalysis.coordinates.base.Timestep._unitcell` attribute.
   ``volume``
       system box volume (derived as the determinant of the box vectors of ``dimensions``)
 
@@ -241,16 +277,18 @@ Private attributes
 
 These attributes are set directly by the underlying trajectory
 readers. Normally the user should not have to directly access those (although in
-some cases it is convenient to directly use :attr:`Timestep._pos`).
+some cases it is convenient to directly use :class:`~MDAnalysis.coordinates.base.Timestep._pos`).
 
   ``_pos``
       raw coordinates, a :class:`numpy.float32` array; ``X = _pos[:,0], Y =
       _pos[:,1], Z = _pos[:,2]``
 
   ``_unitcell``
-      unit cell dimensions and angles; the format depends on the underlying
-      trajectory format. A user should use :attr:`Timestep.dimensions` to
-      access the data in a standard format.
+      native unit cell description; the format depends on the
+      underlying trajectory format. A user should use the
+      :class:`~MDAnalysis.coordinates.base.Timestep.dimensions`
+      attribute to access the data in a canonical format instead of
+      accessing :class:`Timestep._unitcell` directly.
 
 Optional attributes (only implemented by some readers); if an optional
 attribute does not exist, a :exc:`AttributeError` is raised and the calling
@@ -301,6 +339,10 @@ The following methods must be implemented in a Reader class.
      past the last frame
  ``rewind()``
      reposition to first frame
+ ``__entry__()``
+     entry method of a `Context Manager`_ (returns self)
+ ``__exit__()``
+     exit method of a `Context Manager`_, should call ``close()``.
 
 
 **Optional methods**
@@ -429,7 +471,7 @@ Attributes
 Trajectory Writer class
 ~~~~~~~~~~~~~~~~~~~~~~~
 
-Trajectory readers are derived from
+Trajectory writers are derived from
 :class:`MDAnalysis.coordinates.base.Writer`. They are used to write
 multiple frames to a trajectory file. Every time the
 :meth:`~MDAnalysis.coordinates.base.Writer.write` method is called,
@@ -552,7 +594,7 @@ PDB). In theses cases, the kind of writer is selected with the
 
 __all__ = ['reader', 'writer']
 
-import PDB, PQR, DCD, CRD, XTC, TRR, GRO, XYZ, TRJ, PDBQT, LAMMPS
+import PDB, PQR, DCD, CRD, XTC, TRR, GRO, XYZ, TRJ, PDBQT, LAMMPS, DMS, TRZ
 import base
 from core import reader, writer
 
@@ -563,6 +605,7 @@ _trajectory_readers = {'DCD': DCD.DCDReader,
                        'XYZ': XYZ.XYZReader,
                        'TRR': TRR.TRRReader,
                        'PDB': PDB.PDBReader,
+                       'XPDB': PDB.ExtendedPDBReader,
                        'PDBQT': PDBQT.PDBQTReader,
                        'CRD': CRD.CRDReader,
                        'GRO': GRO.GROReader,
@@ -572,6 +615,8 @@ _trajectory_readers = {'DCD': DCD.DCDReader,
                        'PQR': PQR.PQRReader,
                        'LAMMPS': LAMMPS.DCDReader,
                        'CHAIN': base.ChainReader,
+                       'DMS': DMS.DMSReader,
+                       'TRZ': TRZ.TRZReader,
                        }
 
 #: formats of readers that can also handle gzip or bzip2 compressed files
@@ -580,11 +625,13 @@ _compressed_formats = ['XYZ', 'TRJ', 'MDCRD', 'PQR', 'PDBQT']
 #: readers of files that contain both topology/atom data and coordinates
 #: (currently only the keys are used)
 _topology_coordinates_readers = {
-                       'PDB': PDB.PrimitivePDBReader,
+                       'PDB': PDB.PrimitivePDBReader,     # FIXME: should be able to use BioPython PDBReader for topolgy if permissive=False!
+                       'XPDB': PDB.ExtendedPDBReader,
                        'PDBQT': PDBQT.PDBQTReader,
                        'GRO': GRO.GROReader,
                        'CRD': CRD.CRDReader,
                        'PQR': PQR.PQRReader,
+                       'DMS': DMS.DMSReader,
 }
 
 #: hack: readers that ignore most errors (permissive=True); at the moment
@@ -619,5 +666,6 @@ _trajectory_writers = {'DCD': DCD.DCDWriter,
                        'LAMMPS': LAMMPS.DCDWriter,
                        'PDB': PDB.MultiPDBWriter,
                        'NCDF': TRJ.NCDFWriter,
+                       'TRZ':TRZ.TRZWriter,
                        }
 
