@@ -27,7 +27,7 @@ A generic Gromacs_ trajectory is simply called "trj" within this
 module.
 
 .. SeeAlso:: :mod:`MDAnalysis.coordinates.base` for the generic MDAnalysis base
-             classes and :mod:`MDAnalysis.coordinates.xdrfile.libxdrfile` for
+             classes and :mod:`MDAnalysis.coordinates.xdrfile.libxdrfile2` for
              the low-level bindings to the XDR trajectories.
 
 .. _Gromacs: http://www.gromacs.org
@@ -38,6 +38,15 @@ Generic xdr trj classes
 The generic classes are subclassed to generate the specific classes
 for the XTC and TRR format.
 
+.. versionchanged:: 0.8.0
+
+   The XTC/TRR I/O interface now uses
+   :mod:`~MDAnalysis.coordinates.xdrfile.libxdrfile2`, which has seeking and
+   indexing capabilities. Note that unlike
+   :mod:`~MDAnalysis.coordinates.xdrfile.libxdrfile` before it,
+   :mod:`~MDAnalysis.coordinates.xdrfile.libxdrfile2` is distributed under the
+   GNU GENERAL PUBLIC LICENSE, version 2 (or higher).
+
 .. autoclass:: Timestep
    :members:
 .. autoclass:: TrjReader
@@ -52,24 +61,25 @@ import errno
 import numpy
 import sys
 
-import libxdrfile, statno
+import libxdrfile2, statno
 from MDAnalysis.coordinates import base
 from MDAnalysis.coordinates.core import triclinic_box, triclinic_vectors
 
 import MDAnalysis.core
 
+# This is the XTC class. The TRR overrides with it's own.
 class Timestep(base.Timestep):
     """Timestep for a Gromacs trajectory."""
-    def __init__(self, arg):
-        DIM = libxdrfile.DIM    # compiled-in dimension (most likely 3)
+    def __init__(self, arg, **kwargs):
+        DIM = libxdrfile2.DIM    # compiled-in dimension (most likely 3)
         if numpy.dtype(type(arg)) == numpy.dtype(int):
             self.frame = 0
             self.numatoms = arg
-            # C floats and C-order for arrays (see libxdrfile.i)
+            # C floats and C-order for arrays (see libxdrfile2.i)
             self._pos = numpy.zeros((self.numatoms, DIM), dtype=numpy.float32, order='C')
             self._unitcell = numpy.zeros((DIM,DIM), dtype=numpy.float32)
             # additional data for xtc
-            self.status = libxdrfile.exdrOK
+            self.status = libxdrfile2.exdrOK
             self.step = 0
             self.time = 0
             self.prec = 0
@@ -78,7 +88,10 @@ class Timestep(base.Timestep):
             self.frame = arg.frame
             self.numatoms = arg.numatoms
             self._unitcell = numpy.array(arg._unitcell)
-            self._pos = numpy.array(arg._pos)
+            try:
+                self._pos = numpy.array(arg._pos, dtype=numpy.float32)
+            except ValueError as err:
+                raise ValueError("Attempted to create a Timestep with invalid coordinate data: " + err.message)
             for attr in ('status', 'step', 'time', 'prec', 'lmbda'):
                 if hasattr(arg, attr):
                     self.__setattr__(attr, arg.__getattribute__(attr))
@@ -95,7 +108,7 @@ class Timestep(base.Timestep):
                 raise ValueError("XDR timestep has not second dimension 3: shape=%r" % (arg.shape,))
             self._pos = arg.astype(numpy.float32).copy('C')  ## C-order
             # additional data for xtc
-            self.status = libxdrfile.exdrOK
+            self.status = libxdrfile2.exdrOK
             self.step = 0
             self.time = 0
             self.prec = 0
@@ -147,15 +160,21 @@ class TrjWriter(base.Writer):
              skip between subsequent timesteps; only used when *delta* is set.
           *delta*
              timestep to use. If set will override any time information contained in the
-             passed :class:`Timestep` objects; otherwise that will be used. If in the 
-             latter case :attr:`Timestep.time` is unavailable the TrjWriter will default
+             passed :class:`Timestep` objects; otherwise that will be used. If in the
+             latter case :attr:`~Timestep.time` is unavailable the TrjWriter will default
              to setting the trajectory time at 1 MDAnalysis unit (typically 1ps) per step.
           *precision*
-             accuracy for lossy XTC format [1000]
+              accuracy for lossy XTC format as a power of 10 (ignored
+              for TRR) [1000.0]
           *convert_units*
              ``True``: units are converted to the MDAnalysis base format; ``None`` selects
-             the value of :data:`MDAnalysis.core.flags` ['convert_gromacs_lengths'].
+             the value of :data:`MDAnalysis.core.flags` ['convert_lengths'].
              (see :ref:`flags-label`)
+
+        .. versionchanged:: 0.8.0
+           The TRR writer is now able to write TRRs without coordinates/velocities/forces,
+           depending on the properties available in the :class:`Timestep` objects passed to
+           :meth:`~TRRWriter.write`.
         '''
         assert self.format in ('XTC', 'TRR')
 
@@ -170,7 +189,7 @@ class TrjWriter(base.Writer):
                 self.filename = filename.encode("UTF-8")
 
         if convert_units is None:
-            convert_units = MDAnalysis.core.flags['convert_gromacs_lengths']
+            convert_units = MDAnalysis.core.flags['convert_lengths']
         self.convert_units = convert_units    # convert length and time to base units on the fly?
         self.numatoms = numatoms
 
@@ -180,9 +199,12 @@ class TrjWriter(base.Writer):
         self.delta = delta
         self.remarks = remarks
         self.precision = precision  # only for XTC
-        self.xdrfile = libxdrfile.xdrfile_open(self.filename, 'w')
+        self.xdrfile = libxdrfile2.xdrfile_open(self.filename, 'w')
 
         self.ts = None
+        # To flag empty properties to be skipped when writing a TRR it suffices to pass an empty 2D array with shape(natoms,0)
+        if self.format == 'TRR':
+            self._emptyarr = numpy.array([], dtype=numpy.float32).reshape(self.numatoms,0)
 
     def write_next_timestep(self, ts=None):
         ''' write a new timestep to the trj file
@@ -203,7 +225,7 @@ class TrjWriter(base.Writer):
 
         status = self._write_next_timestep(ts)
 
-        if status != libxdrfile.exdrOK:
+        if status != libxdrfile2.exdrOK:
             raise IOError(errno.EIO, "Error writing %s file (status %d)" % (self.format, status), self.filename)
         self.frames_written += 1
 
@@ -225,55 +247,75 @@ class TrjWriter(base.Writer):
             time = (self.start+self.step*self.frames_written)*self.delta
 
         if self.convert_units:
-            # make a copy of the scaled positions so that the in-memory
-            # timestep is not changed (would have lead to wrong results if
-            # analysed *after* writing a time step to disk). The new
-            # implementation could lead to memory problems and/or slow-down for
-            # very big systems because we temporarily create a new array pos
-            # for each frame written
-            pos = self.convert_pos_to_native(ts._pos, inplace=False)
             time = self.convert_time_to_native(time, inplace=False)
-        else:
-            pos = ts._pos
+
         if not hasattr(ts, 'step'):
             # bogus, should be actual MD step number, i.e. frame * delta/dt
             ts.step = ts.frame
         unitcell = self.convert_dimensions_to_unitcell(ts).astype(numpy.float32)  # must be float32 (!)
 
+        # make a copy of the scaled positions so that the in-memory
+        # timestep is not changed (would have lead to wrong results if
+        # analysed *after* writing a time step to disk). The new
+        # implementation could lead to memory problems and/or slow-down for
+        # very big systems because we temporarily create a new array pos
+        # for each frame written
+        #
+        # For TRR only go through the trouble if the frame actually has valid
+        #  coords/vels/forces; otherwise they won't be written anyway (pointers
+        #  set to an empty array that libxdrfile2.py knows it should set to NULL).
+        #
         # (2) have to treat XTC and TRR somewhat differently
         if self.format == 'XTC':
-            status = libxdrfile.write_xtc(self.xdrfile, int(ts.step), float(time), unitcell, pos, self.precision)
+            if self.convert_units:
+                pos = self.convert_pos_to_native(ts._pos, inplace=False)
+            else:
+                pos = ts._pos
+            status = libxdrfile2.write_xtc(self.xdrfile, int(ts.step), float(time), unitcell, pos, self.precision)
+        #
         elif self.format == 'TRR':
             if not hasattr(ts, 'lmbda'):
                 ts.lmbda = 1.0
-            if hasattr(ts, '_velocities'):
+            # Same assignment logic as for TRR Timestep creation (because we might be getting here frames from
+            #  other formats' Timesteps that don't have 'has_' flags).
+            has_x = ts.__dict__.get("has_x", True)
+            has_v = ts.__dict__.get("has_v", hasattr(ts, "_velocities"))
+            has_f = ts.__dict__.get("has_f", hasattr(ts, "_forces"))
+            # COORDINATES
+            if has_x:
+                if self.convert_units:
+                    pos = self.convert_pos_to_native(ts._pos, inplace=False)
+                else:
+                    pos = ts._pos
+            else:
+                pos = self._emptyarr
+            #VELOCITIES
+            if has_v:
                 if self.convert_units:
                     velocities = self.convert_velocities_to_native(ts._velocities, inplace=False)
                 else:
                     velocities = ts._velocities
             else:
-                # 0-velocities (no need to convert those); add it to ts as a sideeffect
-                # so that we don't have to reallocate next time
-                velocities = ts._velocities = numpy.zeros((3,ts.numatoms), dtype=numpy.float32)
-            if hasattr(ts, '_forces'):
+                velocities = self._emptyarr
+            # FORCES
+            if has_f:
                 if self.convert_units:
                     forces = self.convert_forces_to_native(ts._forces, inplace=False)
                 else:
                     forces = ts._forces
             else:
-                # 0-forces (no need to convert those); add it to ts as a sideeffect
-                # so that we don't have to reallocate next time
-                forces = ts._forces = numpy.zeros((3,ts.numatoms), dtype=numpy.float32)
-            status = libxdrfile.write_trr(self.xdrfile, int(ts.step), float(time), float(ts.lmbda), unitcell,
+                forces = self._emptyarr
+            #
+            status = libxdrfile2.write_trr(self.xdrfile, int(ts.step), float(time), float(ts.lmbda), unitcell,
                                           pos, velocities, forces)
         else:
             raise NotImplementedError("Gromacs trajectory format %s not known." % self.format)
         return status
 
     def close(self):
-        status = libxdrfile.exdrCLOSE
+        status = libxdrfile2.exdrCLOSE
         if not self.xdrfile is None:
-            status = libxdrfile.xdrfile_close(self.xdrfile)
+            status = libxdrfile2.xdrfile_close(self.xdrfile)
             self.xdrfile = None
         return status
 
@@ -284,13 +326,13 @@ class TrjWriter(base.Writer):
 class TrjReader(base.Reader):
     """Generic base class for reading Gromacs trajectories inside MDAnalysis.
 
-    Derive classes and set :attr:`TrjReader.format`,
-    :attr:`TrjReader._read_trj` and :attr:`TrjReader._read_trj_atoms`.
+    Derive classes and set :attr:`TrjReader.format`, :attr:`TrjReader._read_trj` and :attr:`TrjReader._read_trj_atoms`.
 
     Example::
        reader = TrjReader("file.trj")
        for ts in reader:
           print ts
+
     """
     #: units of time (ps) and length (nm) in Gromacs
     units = {'time': 'ps', 'length': 'nm'}
@@ -308,9 +350,8 @@ class TrjReader(base.Reader):
             *filename*
                 the name of the trr file.
             *sub*
-
                 an numpy integer array of what subset of trajectory atoms to load into
-                the timestep. Intended to work similarly to the 'sub' argument to gromac's trjconv.
+                the timestep. Intended to work similarly to the 'sub' argument to Gromacs_' trjconv.
 
                 This is usefull when one has a Universe loaded with only an unsolvated protein, and
                 wants to read a solvated trajectory.
@@ -327,14 +368,8 @@ class TrjReader(base.Reader):
             if isinstance(filename, unicode):
                 self.filename = filename.encode("UTF-8")
 
-        # Check if file is not too big file for a 32-bit.
-        # underlying xdrfile is indeed limited by the max integer value
-        if os.path.getsize(filename) > sys.maxint: # This test works even on a 32-bit system
-            raise OSError("Filesize is too big to be handled by xdrfile library (filesize: %.1fMB - max size: %.1fMB)"
-                          % (os.path.getsize(filename)/1.e6, sys.maxint/1.e6))
-
         if convert_units is None:
-            convert_units = MDAnalysis.core.flags['convert_gromacs_lengths']
+            convert_units = MDAnalysis.core.flags['convert_lengths']
         self.convert_units = convert_units  # convert length and time to base units on the fly?
         self.xdrfile = None
 
@@ -351,7 +386,7 @@ class TrjReader(base.Reader):
         self.__trr_numatoms = self._read_trj_natoms(self.filename)
 
         # logic for handling sub sections of trr:
-        # this class has some tmp buffers into which the libxdrfile functions read the
+        # this class has some tmp buffers into which the libxdrfile2 functions read the
         # entire frame, then this class copies the relevant sub section into the timestep.
         # the sub section logic is contained entierly within this class.
 
@@ -364,13 +399,13 @@ class TrjReader(base.Reader):
                 raise ValueError("sub MUST be less than or equal to the number of actual trr atoms, {} in this case".
                                  format(self.__trr_numatoms))
             if numpy.max(sub) >= self.__trr_numatoms or numpy.min(sub) < 0:
-                raise IndexError("sub contains out of range elements for the given trajectory")
+                raise IndexError("sub contains out-of-range elements for the given trajectory")
             # sub appears to be valid
             self.__sub = sub
 
             # make tmp buffers
-            # C floats and C-order for arrays (see libxdrfile.i)
-            DIM = libxdrfile.DIM    # compiled-in dimension (most likely 3)
+            # C floats and C-order for arrays (see libxdrfile2.i)
+            DIM = libxdrfile2.DIM    # compiled-in dimension (most likely 3)
             # both xdr and trr have positions
             self.__pos_buf = numpy.zeros((self.__trr_numatoms, DIM), dtype=numpy.float32, order='C')
             if self.format == "TRR":
@@ -452,9 +487,9 @@ class TrjReader(base.Reader):
     def _read_trj_natoms(self, filename):
         """Generic number-of-atoms extractor with minimum intelligence. Override if necessary."""
         if self.format == 'XTC':
-            numatoms = libxdrfile.read_xtc_natoms(filename)
+            numatoms = libxdrfile2.read_xtc_natoms(filename)
         elif self.format == 'TRR':
-            numatoms = libxdrfile.read_trr_natoms(filename)
+            numatoms = libxdrfile2.read_trr_natoms(filename)
         else:
             raise NotImplementedError("Gromacs trajectory format %s not known." % self.format)
         return numatoms
@@ -462,24 +497,36 @@ class TrjReader(base.Reader):
     def _read_trj_numframes(self, filename):
         """Number-of-frames extractor/indexer for XTC and TRR."""
         if self.format == 'XTC':
-            self.__numframes, self.__offsets = libxdrfile.read_xtc_numframes(filename)
+            self.__numframes, self.__offsets = libxdrfile2.read_xtc_numframes(filename)
         elif self.format == 'TRR':
-            self.__numframes, self.__offsets = libxdrfile.read_trr_numframes(filename)
+            self.__numframes, self.__offsets = libxdrfile2.read_trr_numframes(filename)
         else:
             raise NotImplementedError("Gromacs trajectory format %s not known." % self.format)
         return
 
     def save_offsets(self, filename):
-        """Saves current trajectory offsets into filename (numpy format)."""
+        """Saves current trajectory offsets into *filename*, in numpy format. A ".npy" suffix will be appended to *filename* if not already present.
+
+        :Arguments:
+          *filename*
+              filename in which to save the frame offset numpy array.
+
+        .. versionadded: 0.8.0
+        """
         if self.__offsets is None:
             self._read_trj_numframes(self.filename)
-        with open(filename, 'w') as OFILE:
-            numpy.save(OFILE, self.__offsets)
+        numpy.save(filename, self.__offsets)
 
     def load_offsets(self, filename):
-        """Loads current trajectory offsets from filename (numpy format)."""
-        with open(filename, 'r') as OFILE:
-            self.__offsets = numpy.load(OFILE)
+        """Loads current trajectory offsets from *filename* (in numpy format). No error checking is performed.
+
+        :Arguments:
+          *filename*
+              filename of a saved numpy array with the frame offsets for the loaded trajectory.
+
+        .. versionadded: 0.8.0
+        """
+        self.__offsets = numpy.load(filename)
         self.__numframes = len(self.__offsets)
 
     def open_trajectory(self):
@@ -494,10 +541,10 @@ class TrjReader(base.Reader):
         if not os.path.exists(self.filename):
             # must check; otherwise might segmentation fault
             raise IOError(errno.ENOENT, 'XDR file not found', self.filename)
-        self.xdrfile = libxdrfile.xdrfile_open(self.filename, 'r')
+        self.xdrfile = libxdrfile2.xdrfile_open(self.filename, 'r')
         # reset ts
         ts = self.ts
-        ts.status = libxdrfile.exdrOK
+        ts.status = libxdrfile2.exdrOK
         ts.frame = 0
         ts.step = 0
         ts.time = 0
@@ -511,7 +558,7 @@ class TrjReader(base.Reader):
         """Close xdr trajectory file if it was open."""
         if self.xdrfile is None:
             return
-        libxdrfile.xdrfile_close(self.xdrfile)
+        libxdrfile2.xdrfile_close(self.xdrfile)
         self.xdrfile = None  # guard against  crashing with a double-free pointer
 
     def Writer(self, filename, **kwargs):
@@ -535,7 +582,7 @@ class TrjReader(base.Reader):
         :Returns: appropriate :class:`TrjWriter`
         """
         numatoms = kwargs.pop('numatoms', self.numatoms)
-        kwargs['step'] = self.skip_timestep 
+        kwargs['step'] = self.skip_timestep
         kwargs.setdefault('delta', self.delta)
         try:
             kwargs['start'] = self[0].time/kwargs['delta']
@@ -569,46 +616,49 @@ class TrjReader(base.Reader):
         """Generic ts reader with minimum intelligence. Override if necessary."""
         if ts is None:
             ts = self.ts
+        elif self.format == 'TRR' and not hasattr(ts, '_tpos'): # If a foreign Timestep is passed as the receptacle of the data
+            ts = TRR.Timestep(ts)                               #  we must make sure the access-checking stuff gets set up.
+
         if self.xdrfile is None:
             self.open_trajectory()
 
         if self.format == 'XTC':
             if self.__sub is None:
-                ts.status, ts.step, ts.time, ts.prec = libxdrfile.read_xtc(self.xdrfile, ts._unitcell, ts._pos)
+                ts.status, ts.step, ts.time, ts.prec = libxdrfile2.read_xtc(self.xdrfile, ts._unitcell, ts._pos)
             else:
-                ts.status, ts.step, ts.time, ts.prec = libxdrfile.read_xtc(self.xdrfile, ts._unitcell, self.__pos_buf)
+                ts.status, ts.step, ts.time, ts.prec = libxdrfile2.read_xtc(self.xdrfile, ts._unitcell, self.__pos_buf)
                 ts._pos[:] = self.__pos_buf[self.__sub]
         elif self.format == 'TRR':
             if self.__sub is None:
-                ts.status, ts.step, ts.time, ts.lmbda, has_x, has_v, has_f = libxdrfile.read_trr(self.xdrfile, ts._unitcell, ts._pos,
-                                                                            ts._velocities, ts._forces)
+                ts.status, ts.step, ts.time, ts.lmbda, ts.has_x, ts.has_v, ts.has_f = libxdrfile2.read_trr(self.xdrfile, ts._unitcell, ts._tpos,
+                                                                            ts._tvelocities, ts._tforces)
             else:
-                ts.status, ts.step, ts.time, ts.lmbda, has_x, has_v, has_f  = libxdrfile.read_trr(self.xdrfile, ts._unitcell, self.__pos_buf,
+                ts.status, ts.step, ts.time, ts.lmbda, ts.has_x, ts.has_v, ts.has_f  = libxdrfile2.read_trr(self.xdrfile, ts._unitcell, self.__pos_buf,
                                                                             self.__velocities_buf, self.__forces_buf)
-                ts._pos[:] = self.__pos_buf[self.__sub]
-                ts._velocities[:] = self.__velocities_buf[self.__sub]
-                ts._forces[:] = self.__forces_buf[self.__sub]
+                ts._tpos[:] = self.__pos_buf[self.__sub]
+                ts._tvelocities[:] = self.__velocities_buf[self.__sub]
+                ts._tforces[:] = self.__forces_buf[self.__sub]
         else:
             raise NotImplementedError("Gromacs trajectory format %s not known." % self.format)
 
-        if (ts.status == libxdrfile.exdrENDOFFILE) or \
-                (ts.status == libxdrfile.exdrINT and self.format == 'TRR'):
+        if (ts.status == libxdrfile2.exdrENDOFFILE) or \
+                (ts.status == libxdrfile2.exdrINT and self.format == 'TRR'):
             # seems that trr files can get a exdrINT when reaching EOF (??)
             raise IOError(errno.ENODATA, "End of file reached for %s file" % self.format,
                           self.filename)
-        elif not ts.status == libxdrfile.exdrOK:
+        elif not ts.status == libxdrfile2.exdrOK:
             raise IOError(errno.EFAULT, "Problem with %s file, status %s" %
                           (self.format, statno.errorcode[ts.status]), self.filename)
         if self.convert_units:
             # TRRs have the annoying possibility of frames without coordinates/velocities/forces...
-            if self.format == 'XTC' or has_x:
+            if self.format == 'XTC' or ts.has_x:
                 self.convert_pos_from_native(ts._pos)         # in-place !
             self.convert_pos_from_native(ts._unitcell)        # in-place ! (note: xtc/trr contain unit vecs!)
             ts.time = self.convert_time_from_native(ts.time)  # in-place does not work with scalars
             if self.format == 'TRR':
-                if has_v:
+                if ts.has_v:
                     self.convert_velocities_from_native(ts._velocities) # in-place
-                if has_f:
+                if ts.has_f:
                     self.convert_forces_from_native(ts._forces)     # in-place
         ts.frame += 1
         return ts
@@ -697,18 +747,18 @@ class TrjReader(base.Reader):
         """Traj seeker"""
         if self.format == 'XTC' or self.format == 'TRR':
             if rel:
-                status = libxdrfile.xdr_seek(self.xdrfile, long(pos), libxdrfile.SEEK_CUR)
+                status = libxdrfile2.xdr_seek(self.xdrfile, long(pos), libxdrfile2.SEEK_CUR)
             else:
-                status = libxdrfile.xdr_seek(self.xdrfile, long(pos), libxdrfile.SEEK_SET)
-            if status != libxdrfile.exdrOK:
-                raise IOError(errno.EIO, "Problem seeking to offset %d (relative to current = %s) on file %s, status %s" % (pos, rel, self.filename, status))
+                status = libxdrfile2.xdr_seek(self.xdrfile, long(pos), libxdrfile2.SEEK_SET)
+            if status != libxdrfile2.exdrOK:
+                raise IOError(errno.EIO, "Problem seeking to offset %d (relative to current = %s) on file %s, status %s.\nPerhaps you are trying to read a file >2GB and your system does not have large file support?" % (pos, rel, self.filename, status))
         else:
             raise NotImplementedError("Gromacs trajectory format %s not known." % self.format)
 
     def _tell(self):
         """Traj pos getter"""
         if self.format == 'XTC' or self.format == 'TRR':
-            offset = libxdrfile.xdr_tell(self.xdrfile)
+            offset = libxdrfile2.xdr_tell(self.xdrfile)
         else:
             raise NotImplementedError("Gromacs trajectory format %s not known." % self.format)
         return offset
