@@ -161,6 +161,170 @@ class AroundSelection(Selection):
     def __repr__(self):
         return "<'AroundSelection' "+repr(self.cutoff)+" around "+repr(self.sel)+">"
 
+class SphericalLayerSelection(Selection):
+    def __init__(self, sel, inRadius, exRadius, periodic=None):
+        Selection.__init__(self)
+        self.sel = sel
+        self.inRadius = inRadius
+        self.exRadius = exRadius
+        if periodic is None:
+            self.periodic = flags['use_periodic_selections']
+    def _apply(self,group):
+        # make choosing _fast/_slow configurable (while testing)
+        if flags['use_KDTree_routines'] in (True,'fast','always'):
+            return self._apply_KDTree(group)
+        else:
+            return self._apply_distmat(group)
+    def _apply_KDTree(self, group):
+        """Selection using KDTree but periodic = True not supported.
+        (KDTree routine is ca 15% slower than the distance matrix one)
+        """
+        sys_indices = numpy.array([a.number for a in self._group_atoms_list])
+        sys_coor = Selection.coord[sys_indices]
+        sel_atoms = self.sel._apply(group) ## group is wrong, should be universe (?!)
+        sel_CoG = AtomGroup(sel_atoms).centerOfGeometry()
+        self.ref = numpy.array((sel_CoG[0], sel_CoG[1], sel_CoG[2]))
+        if self.periodic:
+            pass # or warn? -- no periodic functionality with KDTree search
+        from MDAnalysis.KDTree.NeighborSearch import CoordinateNeighborSearch
+        CNS = CoordinateNeighborSearch(sys_coor)  # cache the KDTree for this selection/frame?
+        found_ExtIndices = CNS.search(self.ref,self.exRadius)
+        found_IntIndices = CNS.search(self.ref,self.inRadius)
+        found_indices = list(set(found_ExtIndices) - set(found_IntIndices))
+        res_atoms = [self._group_atoms_list[i] for i in found_indices]  
+        return set(res_atoms)
+    def _apply_distmat(self,group):
+        sel_atoms = self.sel._apply(group) ## group is wrong, should be universe (?!)
+        sel_CoG = AtomGroup(sel_atoms).centerOfGeometry()
+        sys_atoms_list = [a for a in (self._group_atoms)]  # list needed for back-indexing
+        sys_ag = AtomGroup(sys_atoms_list)
+        sel_CoG_str = str("point ") + str(sel_CoG[0]) +" "+str(sel_CoG[1])+ " "+str(sel_CoG[2])+ " "+str(self.exRadius)+" and not point "+str(sel_CoG[0]) +" "+str(sel_CoG[1])+ " "+str(sel_CoG[2])+ " "+str(self.inRadius)
+        sel = sys_ag.selectAtoms(sel_CoG_str)
+        res_atoms = AtomGroup(set(sel))
+        if self.periodic:
+            box = group.dimensions[:3]  # ignored with KDTree
+        else:
+            box = None
+        return set(res_atoms)
+    def __repr__(self):
+        return "<'SphericalLayerSelection' inner radius "+repr(self.inRadius)+", external radius "+repr(self.exRadius)+" centered in "+repr(self.sel)+">"
+
+class SphericalZoneSelection(Selection):
+    def __init__(self, sel, cutoff, periodic=None):
+        Selection.__init__(self)
+        self.sel = sel
+        self.cutoff = cutoff
+        self.sqdist = cutoff*cutoff
+        if periodic is None:
+            self.periodic = flags['use_periodic_selections']
+    def _apply(self,group):
+        # make choosing _fast/_slow configurable (while testing)
+        if flags['use_KDTree_routines'] in (True,'fast','always'):
+            return self._apply_KDTree(group)
+        else:
+            return self._apply_distmat(group)
+    def _apply_KDTree(self, group):
+        """Selection using KDTree but periodic = True not supported.
+        (KDTree routine is ca 15% slower than the distance matrix one)
+        """
+        sys_indices = numpy.array([a.number for a in self._group_atoms_list])
+        sys_coor = Selection.coord[sys_indices]
+        sel_atoms = self.sel._apply(group) ## group is wrong, should be universe (?!)
+        sel_CoG = AtomGroup(sel_atoms).centerOfGeometry()
+        self.ref = numpy.array((sel_CoG[0], sel_CoG[1], sel_CoG[2]))
+        if self.periodic:
+            pass # or warn? -- no periodic functionality with KDTree search
+        from MDAnalysis.KDTree.NeighborSearch import CoordinateNeighborSearch
+        CNS = CoordinateNeighborSearch(sys_coor)  # cache the KDTree for this selection/frame?
+        found_indices = CNS.search(self.ref,self.cutoff)
+        res_atoms = [self._group_atoms_list[i] for i in found_indices]  # make list numpy array and use fancy indexing?
+        return set(res_atoms)
+    def _apply_distmat(self,group):
+        sel_atoms = self.sel._apply(group) ## group is wrong, should be universe (?!)
+        sel_CoG = AtomGroup(sel_atoms).centerOfGeometry()
+        sys_atoms_list = [a for a in (self._group_atoms)]  # list needed for back-indexing
+        sys_ag = AtomGroup(sys_atoms_list)
+        sel_CoG_str = str("point ") + str(sel_CoG[0]) +" "+str(sel_CoG[1])+ " "+str(sel_CoG[2])+ " "+str(self.cutoff)
+        sel = sys_ag.selectAtoms(sel_CoG_str)
+        res_atoms = AtomGroup(set(sel))
+        if self.periodic:
+            box = group.dimensions[:3]  # ignored with KDTree
+        else:
+            box = None
+        return set(res_atoms)
+    def __repr__(self):
+        return "<'SphericalZoneSelection' radius "+repr(self.cutoff)+" centered in "+repr(self.sel)+">"
+
+class CylindricalLayerSelection(Selection):    
+    def __init__(self, sel, inRadius, exRadius, zmax, zmin ,periodic=None):
+        Selection.__init__(self)
+        self.sel = sel
+        self.inRadius = inRadius
+        self.exRadius = exRadius
+        self.inRadiusSq = inRadius * inRadius
+        self.exRadiusSq = exRadius * exRadius
+        self.zmax = zmax
+        self.zmin = zmin
+        self.periodic = flags['use_periodic_selections']
+    def _apply(self,group):
+        #KDTree function not implementable
+        return self._apply_distmat(group)
+    def _apply_distmat(self,group):
+        sel_atoms = self.sel._apply(group)
+        sel_CoG = AtomGroup(sel_atoms).centerOfGeometry()
+        x = Selection.coord._x
+        y = Selection.coord._y
+        z = Selection.coord._z
+        sel_CoG_Zone = (x - sel_CoG[0]) * ( x - sel_CoG[0]) + ( y - sel_CoG[1]) * ( y - sel_CoG[1])
+        sel_CoG_Zone_array = numpy.array([[i] for i in sel_CoG_Zone ])
+        Selection.coord._znp = numpy.array([[i] for i in z ])
+        res_atomsA = [i for i in numpy.any(numpy.logical_and(sel_CoG_Zone_array <= self.exRadiusSq, sel_CoG_Zone_array >= self.inRadiusSq),axis=1).nonzero()[0]] 
+        res_atomsB = [i for i in numpy.any(numpy.logical_and(Selection.coord._znp > self.zmin,Selection.coord._znp < self.zmax),axis=1).nonzero()[0]]   
+        intersectionAB = numpy.intersect1d(res_atomsA,res_atomsB)
+        res_atoms = [self._group_atoms_list[i] for i in intersectionAB ]
+        res_atoms = set(res_atoms)
+        if self.periodic:
+            box = group.dimensions[:3]  
+        else:
+            box = None
+        return set(res_atoms)
+    def __repr__(self):
+        return "<'CylindricalLayerSelection' inner radius "+repr(self.inRadius)+", external radius "+repr(self.exRadius)+", zmax "+repr(self.zmax)+", zmin "+repr(self.zmin)+">"
+
+class CylindricalZoneSelection(Selection):    
+    def __init__(self, sel, exRadius, zmax, zmin ,periodic=None):
+        Selection.__init__(self)
+        self.sel = sel
+        self.exRadius = exRadius
+        self.exRadiusSq = exRadius * exRadius
+        self.zmax = zmax
+        self.zmin = zmin
+        self.periodic = flags['use_periodic_selections']
+    def _apply(self,group):
+        #KDTree function not implementable
+        return self._apply_distmat(group)
+    def _apply_distmat(self,group):
+        sel_atoms = self.sel._apply(group) 
+        sel_CoG = AtomGroup(sel_atoms).centerOfGeometry()
+        x = Selection.coord._x
+        y = Selection.coord._y
+        z = Selection.coord._z
+        sel_CoG_exRad = (x - sel_CoG[0]) * ( x - sel_CoG[0]) + ( y - sel_CoG[1]) * ( y - sel_CoG[1])
+        sel_CoG_exRad_array = numpy.array([[i] for i in sel_CoG_exRad ])
+        Selection.coord._znp = numpy.array([[i] for i in z ])
+        res_atomsA = [i for i in numpy.any(sel_CoG_exRad_array <= self.exRadiusSq,axis=1).nonzero()[0]] 
+        res_atomsB = [i for i in numpy.any(numpy.logical_and(Selection.coord._znp > self.zmin,Selection.coord._znp < self.zmax),axis=1).nonzero()[0]]   
+        intersectionAB = numpy.intersect1d(res_atomsA,res_atomsB)
+        res_atoms = [self._group_atoms_list[i] for i in intersectionAB ]
+        res_atoms = set(res_atoms)
+        if self.periodic:
+            box = group.dimensions[:3]  
+        else:
+            box = None
+        return set(res_atoms)
+    def __repr__(self):
+        return "<'CylindricalZoneSelection' radius "+repr(self.exRadius)+", zmax "+repr(self.zmax)+", zmin "+repr(self.zmin)+">"
+
 class PointSelection(Selection):
     def __init__(self, x, y, z, cutoff, periodic=None):
         Selection.__init__(self)
@@ -246,6 +410,25 @@ class AtomSelection(Selection):
     def __repr__(self):
         return "<'AtomSelection' "+repr(self.segid)+" "+repr(self.resid)+" "+repr(self.name)+" >"
 
+class SelgroupSelection(Selection):
+    def __init__(self, selgroup):
+        Selection.__init__(self)
+        self._grp = selgroup
+    def _apply(self, group):
+        common = numpy.intersect1d(group.atoms.indices(),self._grp.atoms.indices())
+        res_atoms = [i for i in self._grp if i.number in common]
+        return set(res_atoms)
+    def __repr__(self):
+        return "<"+repr(self.__class__.__name__)+">"
+
+class FullSelgroupSelection(Selection):
+    def __init__(self, selgroup):
+        Selection.__init__(self)
+        self._grp = selgroup
+    def _apply(self, group):
+        return set(self._grp._atoms)
+    def __repr__(self):
+        return "<"+repr(self.__class__.__name__)+">"
 
 class StringSelection(Selection):
     def __init__(self, field):
@@ -338,6 +521,7 @@ class ProteinSelection(Selection):
 
       * still missing: Amber N- and C-terminal residue names
 
+    .. SeeAlso:: :func:`MDAnalysis.core.util.convert_aa_code`
     """
     #: Dictionary of recognized residue names (3- or 4-letter).
     prot_res = dict([(x,None) for x in [
@@ -355,7 +539,7 @@ class ProteinSelection(Selection):
                 'ASN1', 'CYS1', 'HISA', 'HISB', 'HIS2',
                 # from Gromacs 4.5.3 amber03.ff/aminoacids.rtp
                 # Amber: there are also the C-term aas: 'CALA', 'CGLY', 'CSER', ...
-                # Amber: there are also the B-term aas: 'NALA', 'NGLY', 'NSER', ...
+                # Amber: there are also the N-term aas: 'NALA', 'NGLY', 'NSER', ...
                 'HID', 'HIE', 'HIP', 'ORN', 'DAB', 'LYN', 'HYP', 'CYM', 'CYX', 'ASH',
                 'GLH',
                 'ACE', 'NME',
@@ -370,31 +554,20 @@ class NucleicSelection(Selection):
 
     Recognized residue names:
 
-    * from the Charmm force field ::
+    * from the CHARMM force field ::
         awk '/RESI/ {printf "'"'"%s"'"',",$2 }' top_all27_prot_na.rtf
     * recognized: 'ADE', 'URA', 'CYT', 'GUA', 'THY'
+    * recognized (CHARMM in Gromacs): 'DA', 'DU', 'DC', 'DG', 'DT'
+
+    .. versionchanged:: 0.8
+       additional Gromacs selections (see also :class:`NucleicXstalSelection`)
     """
-    nucl_res = dict([(x,None) for x in ['ADE', 'URA', 'CYT', 'GUA', 'THY']])
+    nucl_res = dict([(x,None) for x in ['ADE', 'URA', 'CYT', 'GUA', 'THY','DA','DC','DG','DT','RA','RU','RG','RC','A', 'T', 'U', 'C', 'G']])
     def _apply(self, group):
         return set([a for a in group.atoms if a.resname in self.nucl_res])
     def __repr__(self):
         return "<'NucleicSelection' >"
 
-class NucleicXstalSelection(Selection):
-    """A nucleic selection consists of all atoms in nucleic acid residues with PDB-like resnames.
-
-    Recognized residue names:
-
-    * from the Charmm force field::
-        awk '/RESI/ {printf "'"'"%s"'"',",$2 }' top_all27_prot_na.rtf
-    * recognized: 'A', 'U', 'C', 'G', 'DT','DA','DC','DG'
-    """
-    nucl_res = dict([(x,None) for x in ['A', 'U', 'C', 'G', 'DT','DA','DC','DG']])
-    def _apply(self, group):
-        return set([a for a in group.atoms if a.resname in self.nucl_res])
-    def __repr__(self):
-        return "<'NucleicXstalSelection' >"
-
 class BackboneSelection(ProteinSelection):
     """A BackboneSelection contains all atoms with name 'N', 'CA', 'C', 'O'.
 
@@ -408,8 +581,11 @@ class BackboneSelection(ProteinSelection):
 
 class NucleicBackboneSelection(NucleicSelection):
     """A NucleicBackboneSelection contains all atoms with name "P", "C5'", C3'", "O3'", "O5'".
+
+    These atoms are only recognized if they are in a residue matched
+    by the :class:`NucleicSelection`.
     """
-    bb_atoms = dict([(x,None) for x in ['P', 'C5\'', 'C3\'', 'O3\'','O5\'']])
+    bb_atoms = dict([(x,None) for x in ["P", "C5'", "C3'", "O3'", "O5'"]])
     def _apply(self, group):
         return set([a for a in group.atoms if (a.name in self.bb_atoms and a.resname in self.nucl_res)])
     def __repr__(self):
@@ -432,9 +608,9 @@ class BaseSelection(NucleicSelection):
         return "<'BaseSelection' >"
 
 class NucleicSugarSelection(NucleicSelection):
-    """A NucleicSugarSelection contains all atoms with name 'C1\'', 'C2\'','C3\'', 'C4\'', 'O2\'','O4\'','O3\''.
+    """A NucleicSugarSelection contains all atoms with name C1', C2', C3', C4', O2', O4', O3'.
     """
-    sug_atoms = dict([(x,None) for x in ['C1\'', 'C2\'','C3\'', 'C4\'', 'O2\'','O4\'','O3\'']])
+    sug_atoms = dict([(x,None) for x in ['C1\'', 'C2\'','C3\'', 'C4\'','O4\'']])
     def _apply(self, group):
         return set([a for a in group.atoms if (a.name in self.sug_atoms and a.resname in self.nucl_res)])
     def __repr__(self):
@@ -527,6 +703,10 @@ class SelectionParser:
     AND = 'and'
     OR = 'or'
     AROUND = 'around'
+    SPHLAYER = 'sphlayer'
+    SPHZONE = 'sphzone'
+    CYLAYER = 'cylayer'
+    CYZONE = 'cyzone'
     POINT = 'point'
     BYRES = 'byres'
     BONDED = 'bonded'
@@ -555,21 +735,23 @@ class SelectionParser:
     LE = '<='
     EQ = '=='
     NE = '!='
+    SELGROUP = 'group'
+    FULLSELGROUP = 'fullgroup'
 
     classdict = dict([(ALL, AllSelection), (NOT, NotSelection), (AND, AndSelection), (OR, OrSelection),
                       (SEGID, SegmentNameSelection), (RESID, ResidueIDSelection), (RESNUM, ResnumSelection),
                       (RESNAME, ResidueNameSelection), (NAME, AtomNameSelection),
                       (TYPE, AtomTypeSelection), (BYRES, ByResSelection),
                       (BYNUM, ByNumSelection), (PROP, PropertySelection),
-                      (AROUND, AroundSelection), (POINT, PointSelection),
-                      (NUCLEIC, NucleicSelection), (PROTEIN, ProteinSelection),
+                      (AROUND, AroundSelection),(SPHLAYER, SphericalLayerSelection),(SPHZONE, SphericalZoneSelection),  
+                      (CYLAYER, CylindricalLayerSelection), (CYZONE, CylindricalZoneSelection),
+                      (POINT, PointSelection),(NUCLEIC, NucleicSelection), (PROTEIN, ProteinSelection),
                       (BB, BackboneSelection), (NBB, NucleicBackboneSelection),
                       (BASE, BaseSelection), (SUGAR, NucleicSugarSelection),
-                      (NUCLEICXSTAL, NucleicXstalSelection),
                       #(BONDED, BondedSelection), not supported yet, need a better way to walk the bond lists
-                      (ATOM, AtomSelection)])
+                      (ATOM, AtomSelection), (SELGROUP, SelgroupSelection), (FULLSELGROUP, FullSelgroupSelection)])
     associativity = dict([(AND, "left"), (OR, "left")])
-    precedence = dict([(AROUND, 1), (POINT, 1), (BYRES, 1), (BONDED, 1), (AND, 3), (OR, 3), (NOT,5 )])
+    precedence = dict([(AROUND, 1),(SPHLAYER, 1),(SPHZONE, 1),(CYLAYER, 1),(CYZONE, 1), (POINT, 1), (BYRES, 1), (BONDED, 1), (AND, 3), (OR, 3), (NOT,5)])
 
     # Borg pattern: http://aspn.activestate.com/ASPN/Cookbook/Python/Recipe/66531
     _shared_state = {}
@@ -596,8 +778,9 @@ class SelectionParser:
         else:
             self.__error(token)
 
-    def parse(self, selectstr):
+    def parse(self, selectstr, selgroups):
         self.selectstr = selectstr
+        self.selgroups = selgroups
         self.tokens = selectstr.replace('(',' ( ').replace(')',' ) ').split()+[self.EOF]
         parsetree = self.__parse_expression(0)
         self.__expect(self.EOF)
@@ -622,6 +805,28 @@ class SelectionParser:
             dist = self.__consume_token()
             exp = self.__parse_expression(self.precedence[op])
             return self.classdict[op](exp, float(dist))
+        elif op in (self.SPHLAYER):
+            inRadius = self.__consume_token()
+            exRadius = self.__consume_token()
+            exp = self.__parse_expression(self.precedence[op])
+            return self.classdict[op](exp, float(inRadius), float(exRadius))
+        elif op in (self.SPHZONE):
+            dist = self.__consume_token()
+            exp = self.__parse_expression(self.precedence[op])
+            return self.classdict[op](exp, float(dist))
+        elif op in (self.CYLAYER):
+            inRadius = self.__consume_token()
+            exRadius = self.__consume_token()
+            zmax = self.__consume_token()
+            zmin = self.__consume_token()            
+            exp = self.__parse_expression(self.precedence[op])
+            return self.classdict[op](exp, float(inRadius), float(exRadius), float(zmax), float(zmin))
+        elif op in (self.CYZONE):
+            exRadius = self.__consume_token()
+            zmax = self.__consume_token()
+            zmin = self.__consume_token()            
+            exp = self.__parse_expression(self.precedence[op])
+            return self.classdict[op](exp, float(exRadius), float(zmax), float(zmin))
         elif op in (self.POINT):
             dist = self.__consume_token()
             x = self.__consume_token()
@@ -640,6 +845,9 @@ class SelectionParser:
             if data in (self.LPAREN, self.RPAREN, self.AND, self.OR, self.NOT, self.SEGID, self.RESID, self.RESNAME, self.NAME, self.TYPE):
                 self.__error("Identifier")
             return self.classdict[op](data)
+        elif op in (self.SELGROUP, self.FULLSELGROUP):
+            grpname = self.__consume_token()
+            return self.classdict[op](self.selgroups[grpname])
         elif op == self.PROTEIN:
             return self.classdict[op]()
         elif op == self.NUCLEIC:
